/v1/projects/{project_id}/virtualbox/vms/{vm_id} — GNS3 1.3.dev1 documentation

### Navigation

- index
- next |
- previous |
- GNS3 1.3.dev1 documentation »
- Virtualbox »

# /v1/projects/{project_id}/virtualbox/vms/{vm_id}

Contents

- /v1/projects/{project_id}/virtualbox/vms/{vm_id}
  - GET /v1/projects/{project_id}/virtualbox/vms/{vm_id}
    - Parameters
    - Response status codes
    - Output
  - PUT /v1/projects/{project_id}/virtualbox/vms/{vm_id}
    - Parameters
    - Response status codes
    - Input
    - Output
  - DELETE /v1/projects/{project_id}/virtualbox/vms/{vm_id}
    - Parameters
    - Response status codes

## GET /v1/projects/{project_id}/virtualbox/vms/{vm_id}

Get a VirtualBox VM instance

### Parameters

- vm_id: UUID for the instance
- project_id: UUID for the project

### Response status codes

- 200: Success
- 400: Invalid request
- 404: Instance doesn’t exist

### Output

Name | Mandatory | Type | Description
--- | --- | --- | ---
adapter_type |  | string | VirtualBox adapter type
adapters |  | integer | number of adapters
console |  | integer | console TCP port
enable_remote_console |  | boolean | enable the remote console
headless |  | boolean | headless mode
name | ✔ | string | VirtualBox VM instance name
project_id | ✔ | string | Project UUID
use_any_adapter |  | boolean | allow GNS3 to use any VirtualBox adapter
vm_id | ✔ | string | VirtualBox VM instance UUID
vmname |  | string | VirtualBox VM name (in VirtualBox itself)

## PUT /v1/projects/{project_id}/virtualbox/vms/{vm_id}

Update a VirtualBox VM instance

### Parameters

- vm_id: UUID for the instance
- project_id: UUID for the project

### Response status codes

- 200: Instance updated
- 400: Invalid request
- 404: Instance doesn’t exist
- 409: Conflict

### Input

Name | Mandatory | Type | Description
--- | --- | --- | ---
adapter_type |  | string | VirtualBox adapter type
adapters |  | integer | number of adapters
console |  | integer | console TCP port
enable_remote_console |  | boolean | enable the remote console
headless |  | boolean | headless mode
name |  | string | VirtualBox VM instance name
use_any_adapter |  | boolean | allow GNS3 to use any VirtualBox adapter
vmname |  | string | VirtualBox VM name (in VirtualBox itself)

### Output

Name | Mandatory | Type | Description
--- | --- | --- | ---
adapter_type |  | string | VirtualBox adapter type
adapters |  | integer | number of adapters
console |  | integer | console TCP port
enable_remote_console |  | boolean | enable the remote console
headless |  | boolean | headless mode
name | ✔ | string | VirtualBox VM instance name
project_id | ✔ | string | Project UUID
use_any_adapter |  | boolean | allow GNS3 to use any VirtualBox adapter
vm_id | ✔ | string | VirtualBox VM instance UUID
vmname |  | string | VirtualBox VM name (in VirtualBox itself)

## DELETE /v1/projects/{project_id}/virtualbox/vms/{vm_id}

Delete a VirtualBox VM instance

### Parameters

- vm_id: UUID for the instance
- project_id: UUID for the project

### Response status codes

- 400: Invalid request
- 404: Instance doesn’t exist
- 204: Instance deleted

### Navigation

- index
- next |
- previous |
- GNS3 1.3.dev1 documentation »
- Virtualbox »